diff --git a/src/caosadvancedtools/models/parser.py b/src/caosadvancedtools/models/parser.py
index b354c42bc555a73e97f69889d4a64b6b50b56c83..25b5727c2674e0fbfa58f31a595da91aebfc806a 100644
--- a/src/caosadvancedtools/models/parser.py
+++ b/src/caosadvancedtools/models/parser.py
@@ -198,7 +198,7 @@ def parse_model_from_json_schema(
         ignored. Default is False.
 
     existing_model : dict, optional
         An existing model to which the created model shall be added.
 
     Returns
     -------
@@ -213,6 +213,9 @@ def parse_model_from_json_schema(
     about the limitations of the current implementation.
 
     """
+    if existing_model is not None:
+        raise NotImplementedError("Adding to an existing model is not implemented yet.")
+
     # @author Florian Spreckelsen
     # @date 2022-02-17
     # @review Timm Fitschen 2023-05-25
@@ -198,7 +198,7 @@ def parse_model_from_json_schema(
 
     existing_model : dict, optional
-        An existing model to which the created model shall be added.
+        An existing model to which the created model shall be added.  Not implemented yet.
 
     Returns